@@ -66,15 +66,17 @@ vcov.mlt <- function(object, parm = coef(object, fixed = FALSE), complete = FALS
 }
 
 logLik.mlt <- function(object, parm = coef(object, fixed = FALSE), 
-                       w = weights(object), newdata, ...) {
+                       w = NULL, newdata, ...) {
     args <- list(...)
     if (length(args) > 0)
         warning("Arguments ", names(args), " are ignored")
     if (!missing(newdata)) {
         tmpmod <- mlt(object$model, data = newdata, dofit = FALSE)
         coef(tmpmod) <- coef(object)
-        return(logLik(tmpmod, parm = parm, w = rep(1, nrow(newdata))))
+        return(logLik(tmpmod, parm = parm, w = w))
     }
+    if (is.null(w))
+        w <- weights(object)
     if (!is.null(object$subset)) {
         ret <- sum(object$logliki(parm, weights = w)[object$subset] * 
                    w[object$subset])
@@ -88,7 +90,7 @@ logLik.mlt <- function(object, parm = coef(object, fixed = FALSE),
 }
 
 estfun.mlt <- function(object, parm = coef(object, fixed = FALSE), 
-                       w = weights(object), newdata, ...) {
+                       w = NULL, newdata, ...) {
     args <- list(...)
     if (length(args) > 0)
         warning("Arguments ", names(args), " are ignored")
@@ -97,6 +99,8 @@ estfun.mlt <- function(object, parm = coef(object, fixed = FALSE),
         coef(tmpmod) <- coef(object)
         return(estfun(tmpmod, parm = parm, weights = w))
     }
+    if (is.null(w))
+        w <- weights(object)
     sc <- -object$score(parm, weights = w)
     if (!is.null(object$subset))
         sc <- sc[object$subset,,drop = FALSE]
